"""
RCK SDK 主客户端类
"""

import logging
from typing import Optional, Dict, Any
from .core.http_client import HTTPClient
from .core.auth import AuthManager
from .compute.kernel import ComputeKernel
from .image.generator import ImageGenerator
from .utils.logger import setup_logger

logger = logging.getLogger(__name__)

class RCKClient:
    """
    RCK Python SDK 主客户端
    
    提供统一的接口访问RCK API的所有功能，包括：
    - 文本计算和分析
    - 图像生成和渲染
    - 多模态资源处理
    
    使用示例:
        client = RCKClient(api_key="your-api-key")
        
        # 文本分析
        result = client.compute.analyze(
            text="床前明月光，疑是地上霜",
            task="分析诗歌的情感和主题"
        )
        
        # 图像生成
        image = client.image.generate(
            prompt="山水画风格的风景",
            composition="远山近水的构图",
            lighting="柔和的晨光",
            style="中国传统水墨画风格"
        )
    """
    
    def __init__(
        self,
        api_key: str,
        base_url: Optional[str] = None,
        timeout: int = 30,
        log_level: int = logging.INFO
    ):
        """
        初始化RCK客户端
        
        :param api_key: Topos API密钥
        :param base_url: API基础URL，默认使用官方地址
        :param timeout: 请求超时时间（秒）
        :param log_level: 日志级别
        """
        # 设置日志
        self.logger = setup_logger("rck_sdk", log_level)
        
        # 初始化认证管理器
        self.auth = AuthManager(api_key)
        
        # 初始化HTTP客户端
        self.http_client = HTTPClient(
            api_key=api_key,
            base_url=base_url,
            timeout=timeout
        )
        
        # 初始化功能模块
        self.compute = ComputeKernel(self.http_client)
        self.image = ImageGenerator(self.http_client)
        
        self.logger.info("RCK Client 初始化成功")
    
    def set_timeout(self, timeout: int) -> None:
        """
        设置请求超时时间
        
        :param timeout: 超时时间（秒）
        """
        self.http_client.timeout = timeout
        self.logger.info(f"请求超时时间已设置为 {timeout} 秒")
    
    def test_connection(self) -> Dict[str, Any]:
        """
        测试与API的连接
        
        :return: 连接测试结果
        """
        try:
            # 执行一个简单的文本分析测试
            result = self.compute.analyze(
                text="测试",
                task="简单分析",
                output_format="basic_analysis"
            )
            
            return {
                "status": "success",
                "message": "连接正常",
                "test_result": result.data
            }
            
        except Exception as e:
            return {
                "status": "error", 
                "message": f"连接失败: {str(e)}",
                "test_result": None
            }
    
    def get_client_info(self) -> Dict[str, Any]:
        """
        获取客户端信息
        
        :return: 客户端配置信息
        """
        return {
            "version": "1.0.0",
            "api_base_url": self.http_client.base_url,
            "timeout": self.http_client.timeout,
            "has_api_key": bool(self.auth.api_key),
            "api_key_valid": self.auth.validate_key()
        }

    # 便捷方法 - 直接在客户端上提供常用功能的快捷访问
    def analyze_text(
        self,
        text: str,
        task: str = "分析文本的情感、主题和内容",
        **kwargs
    ) -> Dict[str, Any]:
        """
        便捷的文本分析方法
        
        :param text: 待分析文本
        :param task: 分析任务
        :param kwargs: 其他参数
        :return: 分析结果
        """
        result = self.compute.analyze(text, task, **kwargs)
        return result.data
    
    def generate_image(
        self,
        prompt: str,
        style: str = "现代数字艺术风格",
        composition: str = "居中构图，画面和谐",
        lighting: str = "自然光照，明亮清晰"
    ) -> 'ImageResponse':
        """
        便捷的图像生成方法
        
        :param prompt: 图像描述
        :param style: 艺术风格
        :param composition: 构图描述
        :param lighting: 光照描述
        :return: 图像响应对象
        """
        return self.image.generate(
            prompt=prompt,
            composition=composition,
            lighting=lighting,
            style=style
        ) 