"""
文本计算核心功能
"""

import logging
from typing import Dict, Any, List, Optional, Union
from ..core.http_client import HTTPClient
from ..models.request import ComputeRequest
from ..models.response import ComputeResponse
from ..utils.validators import validate_string, validate_dict, validate_output_schema
from .schemas import get_schema, PREDEFINED_SCHEMAS

logger = logging.getLogger(__name__)

class ComputeKernel:
    """文本计算核心类"""
    
    def __init__(self, http_client: HTTPClient):
        """
        初始化计算核心
        
        :param http_client: HTTP客户端实例
        """
        self.http_client = http_client
    
    def analyze(
        self,
        text: str,
        task: str,
        output_format: Union[str, Dict[str, Any]] = "basic_analysis",
        **kwargs
    ) -> ComputeResponse:
        """
        文本分析功能
        
        :param text: 待分析的文本
        :param task: 分析任务描述
        :param output_format: 输出格式，可以是预定义格式名称或自定义Schema
        :param kwargs: 其他自定义参数
        :return: 分析结果
        """
        validate_string(text, "text")
        validate_string(task, "task")
        
        # 处理输出格式
        if isinstance(output_format, str):
            if output_format in PREDEFINED_SCHEMAS:
                schema = get_schema(output_format)
            else:
                raise ValueError(f"未知的预定义格式: {output_format}")
        else:
            schema = output_format
            validate_output_schema(schema)
        
        # 创建请求
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=schema,
            custom_fields=kwargs
        )
        
        logger.info(f"执行文本分析: {task[:50]}...")
        
        # 发送请求
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        
        # 返回响应
        return ComputeResponse(response_data.get("end_point", {}))
    
    def create_poem(
        self,
        inspiration: str,
        style: str = "五言绝句",
        resources: Optional[List[Dict[str, str]]] = None
    ) -> ComputeResponse:
        """
        诗歌创作功能
        
        :param inspiration: 创作灵感或主题
        :param style: 诗歌风格
        :param resources: 多模态资源（如图片）
        :return: 创作结果
        """
        task = f"基于给定的灵感创作一首{style}，并说明创作思路"
        
        request = ComputeRequest(
            start_point=inspiration,
            expect_path=task,
            output_schema=get_schema("poem_creation"),
            custom_fields={"style": style},
            resources=resources
        )
        
        logger.info(f"执行诗歌创作: {style}")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {}))
    
    def translate(
        self,
        text: str,
        target_language: str,
        include_cultural_notes: bool = True
    ) -> ComputeResponse:
        """
        文本翻译功能
        
        :param text: 待翻译文本
        :param target_language: 目标语言
        :param include_cultural_notes: 是否包含文化背景说明
        :return: 翻译结果
        """
        if include_cultural_notes:
            task = f"将文本翻译成{target_language}，并提供文化背景说明"
        else:
            task = f"将文本翻译成{target_language}"
        
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=get_schema("translation"),
            custom_fields={
                "target_language": target_language,
                "include_cultural_notes": str(include_cultural_notes)
            }
        )
        
        logger.info(f"执行翻译: 目标语言 {target_language}")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {}))
    
    def custom_compute(
        self,
        text: str,
        task: str,
        output_schema: Optional[Dict[str, Any]] = None,
        resources: Optional[List[Dict[str, str]]] = None,
        **custom_fields
    ) -> ComputeResponse:
        """
        自定义计算功能，提供最大的灵活性
        
        :param text: 输入文本
        :param task: 任务描述
        :param output_schema: 自定义输出格式
        :param resources: 多模态资源
        :param custom_fields: 自定义字段
        :return: 计算结果
        """
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=output_schema,
            custom_fields=custom_fields,
            resources=resources
        )
        
        logger.info(f"执行自定义计算: {task[:50]}...")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {})) 