"""
HTTP客户端封装，处理所有与RCK API的通信
"""

import requests
import logging
from typing import Dict, Any, Optional, List
from .exceptions import APIError, NetworkError, TimeoutError, AuthenticationError

logger = logging.getLogger(__name__)

class HTTPClient:
    """RCK API HTTP客户端"""
    
    def __init__(self, api_key: str, base_url: str = None, timeout: int = 30):
        """
        初始化HTTP客户端
        
        :param api_key: Topos API密钥
        :param base_url: API基础URL
        :param timeout: 请求超时时间（秒）
        """
        self.api_key = api_key
        self.base_url = base_url or "https://relatioe-kernel-zdibtqjzxm.us-west-1.fcapp.run"
        self.timeout = timeout
        
        # 默认请求头
        self.default_headers = {
            "topos-api-key": api_key,
            "Content-Type": "application/json",
            "User-Agent": "RCK-Python-SDK/1.0.0"
        }
    
    def request(
        self,
        method: str,
        endpoint: str,
        data: Dict[str, Any] = None,
        headers: Dict[str, str] = None
    ) -> Dict[str, Any]:
        """
        发送HTTP请求
        
        :param method: HTTP方法
        :param endpoint: API端点
        :param data: 请求数据
        :param headers: 额外的请求头
        :return: 响应数据
        """
        url = f"{self.base_url}{endpoint}"
        
        # 合并请求头
        request_headers = self.default_headers.copy()
        if headers:
            request_headers.update(headers)
        
        logger.debug(f"Sending {method} request to: {url}")
        logger.debug(f"Request data: {data}")
        
        try:
            response = requests.request(
                method=method,
                url=url,
                json=data,
                headers=request_headers,
                timeout=self.timeout
            )
            
            logger.debug(f"Response status: {response.status_code}")
            logger.debug(f"Response body: {response.text}")
            
            # 处理HTTP错误状态码
            if response.status_code == 401:
                raise AuthenticationError("API密钥无效或已过期")
            elif response.status_code == 403:
                raise AuthenticationError("权限不足，请检查API密钥权限")
            elif response.status_code >= 400:
                try:
                    error_data = response.json()
                    error_message = error_data.get('error', f"API请求失败: {response.status_code}")
                except:
                    error_message = f"API请求失败: {response.status_code}"
                
                raise APIError(
                    error_message,
                    status_code=response.status_code,
                    response_data=error_data if 'error_data' in locals() else None
                )
            
            # 解析响应
            response_data = response.json()
            return response_data
            
        except requests.exceptions.Timeout:
            raise TimeoutError(f"请求超时（{self.timeout}秒）")
        except requests.exceptions.ConnectionError:
            raise NetworkError("网络连接失败，请检查网络状态")
        except requests.exceptions.RequestException as e:
            raise NetworkError(f"网络请求失败: {str(e)}")
    
    def post(self, endpoint: str, data: Dict[str, Any] = None) -> Dict[str, Any]:
        """发送POST请求"""
        return self.request("POST", endpoint, data)
    
    def get(self, endpoint: str) -> Dict[str, Any]:
        """发送GET请求"""
        return self.request("GET", endpoint) 