"""
图像生成核心功能
"""

import logging
from typing import Optional, List
from ..core.http_client import HTTPClient
from ..models.request import ImageRequest
from ..models.response import ImageResponse
from ..utils.validators import validate_string
from .utils import validate_image_params, save_images

logger = logging.getLogger(__name__)

class ImageGenerator:
    """图像生成核心类"""
    
    def __init__(self, http_client: HTTPClient):
        """
        初始化图像生成器
        
        :param http_client: HTTP客户端实例
        """
        self.http_client = http_client
    
    def generate(
        self,
        prompt: str,
        composition: str,
        lighting: str,
        style: str
    ) -> ImageResponse:
        """
        生成图像
        
        :param prompt: 图像描述提示词
        :param composition: 画面构图描述
        :param lighting: 光照描述
        :param style: 艺术风格描述
        :return: 图像生成结果
        """
        # 参数验证
        validate_string(prompt, "prompt")
        validate_image_params(composition, lighting, style)
        
        # 创建请求
        request = ImageRequest(
            start_point=prompt,
            composition=composition,
            lighting=lighting,
            style=style
        )
        
        logger.info(f"开始生成图像: {prompt[:50]}...")
        logger.debug(f"风格: {style[:30]}...")
        
        # 发送请求
        response_data = self.http_client.post("/sd2is/render", request.to_dict())
        
        # 解析响应
        image_response = ImageResponse.from_dict(response_data.get("end_point", {}))
        
        logger.info(f"图像生成完成: {image_response.count} 张图像")
        
        return image_response
    
    def generate_from_mermaid(
        self,
        mermaid_diagram: str,
        composition: str,
        lighting: str, 
        style: str
    ) -> ImageResponse:
        """
        从Mermaid图表生成图像
        
        :param mermaid_diagram: Mermaid图表描述
        :param composition: 画面构图描述
        :param lighting: 光照描述
        :param style: 艺术风格描述
        :return: 图像生成结果
        """
        return self.generate(
            prompt=mermaid_diagram,
            composition=composition,
            lighting=lighting,
            style=style
        )
    
    def generate_art_styles(
        self,
        prompt: str,
        styles: List[str],
        composition: str = "经典构图，画面和谐平衡",
        lighting: str = "自然光照，柔和明亮"
    ) -> List[ImageResponse]:
        """
        生成多种艺术风格的图像
        
        :param prompt: 图像描述提示词
        :param styles: 艺术风格列表
        :param composition: 画面构图描述
        :param lighting: 光照描述
        :return: 多个图像生成结果
        """
        results = []
        
        for style in styles:
            logger.info(f"生成 {style} 风格图像...")
            try:
                result = self.generate(
                    prompt=prompt,
                    composition=composition,
                    lighting=lighting,
                    style=style
                )
                results.append(result)
            except Exception as e:
                logger.error(f"生成 {style} 风格图像失败: {e}")
        
        return results
    
    def save_images(
        self,
        image_response: ImageResponse,
        base_filename: str = "generated",
        output_dir: str = "."
    ) -> List[str]:
        """
        保存图像到本地
        
        :param image_response: 图像响应对象
        :param base_filename: 基础文件名
        :param output_dir: 输出目录
        :return: 保存的文件路径列表
        """
        return save_images(image_response, base_filename, output_dir)
