"""
图像处理工具函数
"""

import base64
import logging
from typing import List, Optional
from ..models.response import ImageResponse, ImageInfo

logger = logging.getLogger(__name__)

def save_images(
    image_response: ImageResponse,
    base_filename: str = "generated",
    output_dir: str = "."
) -> List[str]:
    """
    保存图像到本地文件
    
    :param image_response: 图像响应对象
    :param base_filename: 基础文件名
    :param output_dir: 输出目录
    :return: 保存的文件路径列表
    """
    import os
    import requests
    
    saved_files = []
    
    if not image_response.success:
        logger.warning("图像响应不成功，无法保存")
        return saved_files
    
    # 确保输出目录存在
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)
    
    logger.info(f"开始保存 {len(image_response.images)} 张图像...")
    
    for i, image_info in enumerate(image_response.images):
        try:
            # 获取图像数据
            if image_info.image_data:
                # Base64解码
                image_data = base64.b64decode(image_info.image_data)
            elif image_info.url:
                # 从URL下载
                response = requests.get(image_info.url)
                response.raise_for_status()
                image_data = response.content
            else:
                logger.warning(f"图像 {i} 没有可用的数据源")
                continue
            
            # 确定文件扩展名
            ext = _get_file_extension(image_info.mime_type)
            
            # 生成文件名
            if len(image_response.images) == 1:
                filename = f"{base_filename}.{ext}"
            else:
                filename = f"{base_filename}_{i + 1}.{ext}"
            
            filepath = os.path.join(output_dir, filename)
            
            # 保存文件
            with open(filepath, 'wb') as f:
                f.write(image_data)
            
            saved_files.append(filepath)
            logger.info(f"✅ 图像 {i + 1} 已保存: {filepath} ({len(image_data)} bytes)")
            
        except Exception as e:
            logger.error(f"❌ 保存图像 {i + 1} 失败: {e}")
    
    logger.info(f"成功保存 {len(saved_files)} 张图像")
    return saved_files

def _get_file_extension(mime_type: str) -> str:
    """根据MIME类型确定文件扩展名"""
    mime_to_ext = {
        'image/png': 'png',
        'image/jpeg': 'jpg',
        'image/jpg': 'jpg', 
        'image/webp': 'webp',
        'image/gif': 'gif',
        'image/bmp': 'bmp'
    }
    
    return mime_to_ext.get(mime_type.lower(), 'png')

def validate_image_params(composition: str, lighting: str, style: str) -> None:
    """验证图像生成参数"""
    from ..utils.validators import validate_string
    
    validate_string(composition, "composition", max_length=500)
    validate_string(lighting, "lighting", max_length=300)
    validate_string(style, "style", max_length=300)