"""
响应数据模型
"""

from typing import Dict, Any, List, Optional
from dataclasses import dataclass

@dataclass
class ComputeResponse:
    """文本计算响应模型"""
    raw_data: Dict[str, Any]
    
    @property
    def data(self) -> Dict[str, Any]:
        """获取响应数据"""
        return self.raw_data
    
    def get(self, key: str, default: Any = None) -> Any:
        """获取特定字段的值"""
        return self.raw_data.get(key, default)
    
    def __getitem__(self, key: str) -> Any:
        """支持字典式访问"""
        return self.raw_data[key]
    
    def __contains__(self, key: str) -> bool:
        """支持 in 操作符"""
        return key in self.raw_data
    
    def keys(self):
        """获取所有键"""
        return self.raw_data.keys()
    
    def values(self):
        """获取所有值"""
        return self.raw_data.values()
    
    def items(self):
        """获取所有键值对"""
        return self.raw_data.items()

@dataclass
class ImageInfo:
    """单个图像信息"""
    url: Optional[str] = None
    image_data: Optional[str] = None
    index: int = 0
    size: int = 0
    mime_type: str = "image/png"
    
    @classmethod
    def from_dict(cls, data: Dict[str, Any]) -> 'ImageInfo':
        """从字典创建ImageInfo对象"""
        return cls(
            url=data.get('url'),
            image_data=data.get('imageData'),
            index=data.get('index', 0),
            size=data.get('size', 0),
            mime_type=data.get('mimeType', 'image/png')
        )
    
    @property
    def has_data(self) -> bool:
        """检查是否有可用的图像数据"""
        return bool(self.url or self.image_data)

@dataclass
class ImageResponse:
    """图像生成响应模型"""
    images: List[ImageInfo]
    count: int
    status: str
    raw_data: Dict[str, Any]
    
    @classmethod
    def from_dict(cls, data: Dict[str, Any]) -> 'ImageResponse':
        """从API响应创建ImageResponse对象"""
        images_data = data.get('images', [])
        images = [ImageInfo.from_dict(img) for img in images_data]
        
        return cls(
            images=images,
            count=data.get('count', len(images)),
            status=data.get('status', 'success'),
            raw_data=data
        )
    
    @property
    def success(self) -> bool:
        """判断请求是否成功"""
        return self.status == 'success' and self.count > 0
    
    def __len__(self) -> int:
        """支持len()函数"""
        return len(self.images)
    
    def __getitem__(self, index: int) -> ImageInfo:
        """支持索引访问"""
        return self.images[index]
    
    def __iter__(self):
        """支持迭代"""
        return iter(self.images)