"""
参数验证工具
"""

from typing import Any, Dict, List, Optional, Union
from ..core.exceptions import ValidationError

def validate_required(value: Any, field_name: str) -> None:
    """验证必填字段"""
    if value is None or value == "":
        raise ValidationError(f"字段 '{field_name}' 是必填的", field_name)

def validate_string(value: Any, field_name: str, max_length: Optional[int] = None) -> None:
    """验证字符串字段"""
    validate_required(value, field_name)
    
    if not isinstance(value, str):
        raise ValidationError(f"字段 '{field_name}' 必须是字符串类型", field_name)
    
    if max_length and len(value) > max_length:
        raise ValidationError(f"字段 '{field_name}' 长度不能超过 {max_length} 个字符", field_name)

def validate_dict(value: Any, field_name: str) -> None:
    """验证字典字段"""
    validate_required(value, field_name)
    
    if not isinstance(value, dict):
        raise ValidationError(f"字段 '{field_name}' 必须是字典类型", field_name)

def validate_list(value: Any, field_name: str, min_length: Optional[int] = None) -> None:
    """验证列表字段"""
    validate_required(value, field_name)
    
    if not isinstance(value, list):
        raise ValidationError(f"字段 '{field_name}' 必须是列表类型", field_name)
    
    if min_length and len(value) < min_length:
        raise ValidationError(f"字段 '{field_name}' 至少需要 {min_length} 个元素", field_name)

def validate_output_schema(schema: Dict[str, Any]) -> None:
    """验证输出格式schema"""
    validate_dict(schema, "output_schema")
    
    if "type" not in schema:
        raise ValidationError("output_schema 必须包含 'type' 字段", "output_schema")
    
    if schema["type"] != "object":
        raise ValidationError("output_schema 的 'type' 必须是 'object'", "output_schema")
    
    if "properties" not in schema:
        raise ValidationError("output_schema 必须包含 'properties' 字段", "output_schema") 